# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.file_service_api import FileServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestFileServiceApi(unittest.TestCase):
    """FileServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.file_service_api.FileServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_object_download_presigned_url(self):
        """Test case for get_object_download_presigned_url

        """
        pass

    def test_list_files(self):
        """Test case for list_files

        """
        pass


if __name__ == '__main__':
    unittest.main()
